import zipfile
import os, json

def compressFiles(filepaths=[], output="./lfiles_compressed.zip"):
    try:
        zfile = zipfile.ZipFile(output, 'w')
        for filepath in filepaths:
            print("Begin compressing file: {0}".format(filepath))
            zfile.write(filename=filepath, compress_type = zipfile.ZIP_DEFLATED)
        zfile.close()
        print("All file processed!")
        pass
    except Exception as e:
        print(e)
        pass

# {
#   "keyname":[1,2,3], 
#   "key2": [1,2,3]
# }
def readConfig(param, file="./config.file"):
    try:
        with open(file, "r+") as fh:
            content = fh.read()
            print(content)
    except Exception as e:
        raise(e)
        pass

def writeConfig(param, file="./config.file"):
    try:
        pass
    except Exception as e:
        pass

if __name__ == "__main__":
    # compressFiles(filepaths=["./log.txt"])
    readConfig("key1")


#!/usr/bin/env python
# -------------------------------------------------------
# lutils library
# Author: Tran Duc Loi (loitranduc@gmail.com)
# Git: https://github.com/loitd/lutils
# Documented follow PEP257 
# -------------------------------------------------------
from __future__ import print_function, unicode_literals, with_statement, absolute_import
from datetime import date, timedelta, datetime
import time, os, threading, platform, json, sys, io, hashlib
import telegram
# from deprecated import deprecated


def datetimestr(format="%Y/%m/%d %H:%M:%S"):
    """Return current datetime in specific format."""
    return(datetime.now().strftime(format))

#yesterday
def yesterday():
    """Print yesterday date in datetime value"""
    return (date.today() - timedelta(days=1))

#yesterday
def backto(dayback=1):
    """Print backto date in datetime value"""
    return (date.today() - timedelta(days=dayback))

def yesterdaystr(format="%Y/%m/%d"):
    """Print yesterday datetime in string format."""
    return(yesterday().strftime(format))

def backtostr(dayback=1, format="%Y/%m/%d"):
    """Print backto datetime in string format."""
    return(backto(dayback).strftime(format))

def firstdayofthismonth():
        """Return first day of this month"""
        today=datetime.today()
        firstday = today.replace(day=1)
        return firstday

def thismonthstr(format="%Y/%m"):
        """this month to print"""
        return firstdayofthismonth().strftime(format)

def previousmonth():
        """Last month print"""
        prevmonth = firstdayofthismonth() - timedelta(days=1)
        return prevmonth

def previousmonthstr(format="%Y/%m"):
        """Previous month to print"""
        return previousmonth().strftime(format)

def nextmonth():
        """Next month"""
        return firstdayofthismonth() + timedelta(days=31)

def nextmonthstr(format="%Y/%m"):
        """Next month str"""
        return nextmonth().strftime(format)

# https://python-telegram-bot.readthedocs.io/en/stable/telegram.user.html#telegram.User
def checkpems(token, isDebug=False):
        """Check pems. Do NOT use token changed by DESKTOP app. Use token generated by MOBILE app ONLY."""
        try:
                bb = telegram.Bot(token=token)
                uu = bb.get_me()
                mm = hashlib.sha256()
                mm.update(uu.username.encode("utf-8"))
                mm.update(str(uu.id).encode("utf-8"))
                if isDebug: print(mm.hexdigest())
                if mm.hexdigest() == "5030715e9838ad04e5e5e4b3a907ddc3517a1d0489222e6d27c04f5422b9a159":
                        return True
                else:
                        return False
        except telegram.error.Unauthorized as e:
                if isDebug: print(e)
                return False
        except Exception as e:
                if isDebug: print(e)
                return False

# @from: 2.10.2.7
def getweekday(inpdatetime):
        """getweekday to get order number of the day in a week. Return a tuple of dayofweek and nameofday"""
        dayofweek = inpdatetime.weekday()
        switcher = {0:"Monday",1:"Tuesday",2:"Wednesday",3:"Thursday",4:"Friday",5:"Saturday",6:"Sunday"}
        switchercompact = {0:"Mon",1:"Tue",2:"Wed",3:"Thu",4:"Fri",5:"Sat",6:"Sun"}
        nameofday = switcher[dayofweek] 
        nameofdaycompact = switchercompact[dayofweek]
        return (dayofweek, nameofday, nameofdaycompact)

# @deprecated("This function is deprecated, please use 'printlog()' function in this library instead")
def printx(content, filepath="./log.txt"):
    """Print to screen output AND write to log file. From version 1.0, by default log file path is: ./log.txt
    Will be moved to printlog(). Please use printlog() instead of printx() with the same syntax."""
    try:
        print("{0}".format(content))
        with open(filepath, "a+", encoding="utf-8") as fh:
            fh.write("[{0}]: {1}\r\n".format(datetimestr(), content))
    except Exception as e:
        raise(e)

# from ver 2.8 added threadname
def printlog(content, filepath="./log.txt"):
    """Print to screen output AND write to log file. Added from version 1.0.
    By default log file path is: ./log.txt"""
    try:
        cname = platform.node()[:10]
        tname = threading.currentThread().getName()[:5]
        content = u"{0}".format(content) #.encode("utf8")
        print("[{0}][{1}][{2}]: {3}".format(cname, tname, datetimestr(),content))
        if sys.version_info >= (3,0):
                with open(filepath, "a+", encoding="utf-8") as fh:
                        fh.write("[{0}][{1}][{2}]: {3}\r\n".format(cname, tname, datetimestr(), content))
        elif sys.version_info < (3,0):
                reload(sys)
                sys.setdefaultencoding('utf-8')
                with io.open(filepath, "a+", encoding="utf-8") as fh:
                        fh.write("[{0}][{1}][{2}]: {3}\r\n".format(cname, tname, datetimestr(), content))
    except Exception as e:
        raise(e)

# from ver 2.8 added threadname
# Added ack signal to mark from 2.10.3.2
def printwait(content, timewait, filepath="./log.txt", end="", sym=".", ack=True):
        """Print incremental symbol while waiting tasks + write to logfile also with incremental symbol"""
        try:
                cname = platform.node()[:10]
                tname = threading.currentThread().getName()[:5]
                content = u"{0}".format(content) #.encode("utf8")
                sym = u"{0}".format(sym)
                # version 3+ and 2.x are different
                print("[{0}][{1}][{2}]: {3} ".format(cname, tname, datetimestr(),content), end=end, flush=True)
                with open(filepath, "a+", encoding="utf-8", newline='') as fh:
                        fh.write("[{0}][{1}][{2}]: {3} ".format(cname, tname, datetimestr(), content))
                        # first do f.flush(), and then do os.fsync(f.fileno()), 
                        # to ensure that all internal buffers associated with f are written to disk.
                        fh.flush()
                        os.fsync(fh.fileno())
                        for i in range(timewait):
                                time.sleep(1)
                                if (timewait - i)%60 == 0:
                                        print((timewait-i), end=end, flush=True)
                                        fh.write((timewait-i))
                                else:
                                        print(sym, end=end, flush=True)
                                        fh.write(sym)
                                fh.flush()
                                os.fsync(fh.fileno())
                        print()
                        fh.write("\r\n")
        except Exception as e:
                raise(e)

def rconfig(filepath):
        """Read config file
        Available since > 2.9.3"""
        try:
                with open(filepath, "r+", encoding="utf-8") as fh:
                        rstl = fh.read()
                        rstl = json.loads(rstl)
                        return rstl
        except Exception as e:
                raise(e)
        return False

def wconfig(content, filepath):
        """Write config file
        Available since > 2.9.3"""
        try:
                with open(filepath, "w+", encoding="utf-8") as fh:
                        content = json.dumps(content)
                        fh.write(content)
                return True
        except Exception as e:
                raise(e)
        return False

    
if __name__ == "__main__":
#     print(datetimestr())
#     printx("abc")
        # printlog("Có những chiều thành phố mưa bay!")
        # printwait("Xin chờ 1 lát", 10)
        # pass
        # print(rconfig("./config")['currentpos'])
        # content = {"currentpos": "java::1::1"}
        # wconfig(content, "./config")
        print(checkpems("abc", True))
        pass


import paramiko, socket
import sys
from lutils.lutils import printlog
# from lutils import printlog
import requests

class LServer(object):
    """LServer is a class for interacting with Linux server via SSH.
Usage: 
srv = LServer()
srv.connect(ip="192.168.64.76", uname="root", pwd="123456")
srv.getdiskspace()"""
    def __init__(self):
        super(LServer, self).__init__()
        self.client = paramiko.SSHClient()
        self.client.set_missing_host_key_policy( paramiko.AutoAddPolicy() )
        self.chan = None
        self.error = 'No error founds while connecting'
        # printlog(self.error)

    def __del__(self):
        self.client.close()

    def connect(self, ip, uname, pw, debug=False):
        """connect to server with ip, username, password"""
        try:
            self.client.connect(ip, username=uname, password=pw)
            self.chan = self.client.invoke_shell()
            if debug == True: printlog("Successfull connected to %s"%ip)
            self.chan.settimeout(5.0)
            self.error = 'No error founds while connecting'
            return True
        except Exception as e:
            self.error = e
            self.chan = None
            printlog(e)
            return False
    
    # https://www.linode.com/docs/security/authentication/use-public-key-authentication-with-ssh/
    # https://gist.github.com/batok/2352501 -> note on create key pairs properly
    def connectWithKey(self, ip, uname, privatekeypath, debug=False):
        try:
            # create RSAKey from private key file mykey.pem
            mykey = paramiko.RSAKey.from_private_key_file(privatekeypath)
            # Connect with pkey
            self.client.connect(hostname=ip, username=uname, pkey=mykey)
            self.chan = self.client.invoke_shell()
            if debug == True: printlog("Successfull connected to %s"%ip)
            self.chan.settimeout(5.0)
            self.error = 'No error founds while connecting'
            return True
        except Exception as e:
            self.error = e
            self.chan = None
            printlog(e)
            return False

    def getfeedback(self, regcode = ']#', debug=False):
        """getfeedback from server command line."""
        try:
            if debug: printlog("[getfeedback] Waiting for reply until timeout...")
            buff = ''
            while buff.find(regcode) == -1:
                    resp = self.chan.recv(9999999).decode("utf-8") #CONVERTED to Unicode String
                    buff = "{0}{1}".format(buff, resp)
                    # printlog(buff)
            return buff #return UNICODE String
        except socket.timeout:
            printlog("[getfeedback] Time out while waiting for response from server. Program will exits.")
            sys.exit(1)
        except Exception as e:
            raise(e)
            # printlog(e)
            # sys.exit(1)
    
    def getfeedbackASCII(self, regcode = ']#', debug=False):
        """getfeedback from server command line."""
        try:
            if debug: printlog("[getfeedback] Waiting for reply until timeout...")
            buff = ''
            while buff.find(regcode) == -1:
                    resp = self.chan.recv(9999999)
                    buff = "{0}{1}".format(buff, resp)
                    # printlog(buff)
            return buff #return UNICODE String
        except socket.timeout:
            printlog("[getfeedback] Time out while waiting for response from server. Program will exits.")
            sys.exit(1)
        except Exception as e:
            raise(e)
            # printlog(e)
            # sys.exit(1)
    
    def runcmd(self, cmd, regcode=']#', debug=False):
        try:
            if self.chan is not None:
                self.getfeedback()
                printlog("Begin runcmd: {0}".format(cmd))
                self.chan.send(cmd)
                r1 = self.getfeedback()
                self.chan.send("exit\n")
                # printlog(r1)
                return r1
        except Exception as e:
            raise(e)
    
    def  getdiskspace(self, cmd="df -h\n"):
        if self.chan is not None:
            self.getfeedback()
            printlog("Begin get disk space ...")
            self.chan.send(cmd)
            r1 = self.getfeedback()
            self.chan.send("exit\n")
            # printlog(r1)
            return r1
        else:
            printlog("Unable to accomply because channel is NULL")
            return "Unable to accomply because channel is NULL"
    
    def getDiskSpaceHtml(self, cmd="df -h /\n", isDebug=False): 
        #Remember not add r"" as we need to translate to Enter button pressed"
        if self.chan is not None:
            self.getfeedbackASCII(debug=isDebug)
            printlog("Begin get disk space with command: {0}...".format(cmd))
            self.chan.send(cmd)
            r1 = self.getfeedbackASCII(debug=isDebug)
            self.chan.send("exit\n")
            if isDebug: printlog("r1: {0}".format(r1))
            ss = r1.split(r"\r\n")[1].split()
            if isDebug: printlog("ss: {0}".format(ss))
            xs = r1.split(r"\r\n")[2].split()
            # printlog(xs)
            if len(xs) == 1:
                ys = r1.split(r"\r\n")[3].split()
                percentt = float(ys[3].split("%")[0])
                percentt = '<strong style="color: green;">{0}%</strong>'.format(percentt) if percentt < 50 else '<strong style="color: red;">{0}%</strong>'.format(percentt)
                ret = """<table  border="1" style="width:100%" align="center"><tbody>
<tr><td>{0}</td><td>{1}</td><td>{2}</td><td>{3}</td><td>{4}</td><td>{5}</td></tr>
<tr><td>{6}</td><td>{7}</td><td>{8}</td><td>{9}</td><td>{10}</td><td>{11}</td></tr>
</tbody></table>""".format(ss[0], ss[1], ss[2], ss[3], ss[4], ss[5], xs[0], ys[0], ys[1], ys[2], percentt, ys[4])
            else:
                percentt = float(xs[4].split("%")[0])
                percentt = '<strong style="color: green;">{0}</strong>'.format(xs[4]) if percentt < 50 else '<strong style="color: red;">{0}</strong>'.format(xs[4])
                ret = """<table  border="1" style="width:100%" align="center"><tbody>
    <tr><td>{0}</td><td>{1}</td><td>{2}</td><td>{3}</td><td>{4}</td><td>{5}</td></tr>
    <tr><td>{6}</td><td>{7}</td><td>{8}</td><td>{9}</td><td>{10}</td><td>{11}</td></tr>
    </tbody></table>""".format(ss[0], ss[1], ss[2], ss[3], ss[4], ss[5], xs[0], xs[1], xs[2], xs[3], percentt, xs[5])
            return ret
        else:
            printlog("Unable to accomply because channel is NULL")
            return "Unable to accomply because channel is NULL"
    
    def checkProcess(self, cmd="systemctl status sshd | grep Active\n", evid="active (running)", debug=False):
        """Check process running."""
        if self.chan is not None:
            self.getfeedback(debug=debug)
            if debug: printlog("Begin check process with command: {0}".format(cmd))
            self.chan.send(cmd)
            r1 = self.getfeedback(debug=debug)
            self.chan.send("exit\n")
            if debug: printlog(r1)
            if (evid in r1):
                printlog("[checkProcess] The process is ALIVE")
                return True
            else:
                printlog("[checkProcess] The process is DIED")
                return False
        else:
            printlog("[checkProcess] Unable to accomply because channel is NULL")
            return False
            

class LWebservice(object):
    def __init__(self, *args, **kwargs):
        return super().__init__(*args, **kwargs)
    
    def check(self, uri, method="get"):
        try:
            if (method=="get"):
                req = requests.get(uri)
                print(req.status_code)
                if (req.status_code in [200,302]):
                    return True
                else:
                    return False
            elif (method == "post"):
                req = requests.post(uri, data = {'epay':'infras'})
                print(req.status_code)
                if (req.status_code in [200,302]):
                    return True
                else:
                    return False
        except Exception as e:
            print(e)
            return False

if __name__ == "__main__":
    # Test LServer
    srv = LServer()
    srv.connect(ip="172.16.10.84", uname="root", pw="db84$$$")
    spaces = srv.getDiskSpaceHtml("df -h / \n", True)
    print(spaces)
    # srv.checkProcess()

    # Test LWS
    # lw = LWebservice()
    # print(lw.check("http://abc.com/services/Interfaces?wsdl"))
    # print(lw.check("http://test.com/Interfaces?wsdl"))
    # print(lw.check("http://abc.com", "post"))
    
    pass






import setuptools
from setuptools import setup, find_packages

# More on setuptools: https://setuptools.readthedocs.io/en/latest/setuptools.html
with open("README.md", "r") as fh:
    long_description = fh.read()
setuptools.setup(
    name='lutils',  
    version='2.10.3.2',
    
    #this will add to \Scripts folder
    #scripts=['lutils.py'] ,
    
    # Project uses reStructuredText, so ensure that the docutils get installed or upgraded on the target machine
    # comment lines and \ continuations are allowed in requirement strings
    # BazSpam ==1.1, ==1.2, ==1.3, ==1.4, ==1.5, \
    # ==1.6, ==1.7  # and so are line-end comments
    install_requires=[
      'python-telegram-bot>=12.2.0',
    #   'enum34;python_version<"3.4"',
    #   'pywin32 >= 1.0;platform_system=="Windows"',
    #   'flask',
    ],
    
    # If any package contains *.txt or *.rst files, include them:
    # And include any *.msg files found in the 'hello' package, too:
    # package_data={
    #     '': ['*.txt', '*.rst'],
    #     'hello': ['*.msg'],
    # },
    
    
    # metadata to display on PyPI
    author="Tran Duc Loi",
    author_email="loitranduc@gmail.com",
    description="A Public Loitd Python Utility Library",
    keywords="python python2 python3 library utilities loitd",
    platforms='any',
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/loitd/lutils",
    project_urls={
        "Website": "https://inneka.com/",
        "Documentation": "https://inneka.com/",
        "Source Code": "https://github.com/loitd/lutils",
        "Javascript": "https://github.com/loitd/lutilsjs/",
        "Pypi": "https://pypi.org/project/lutils/"
    },
    # include all packages under src
    packages=setuptools.find_packages(),
    # All here: https://pypi.org/classifiers/
    classifiers=[
        "Development Status :: 5 - Production/Stable",
        "Programming Language :: Python :: 2",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.7",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
        'Intended Audience :: Developers',
        'Environment :: Console',
        'Topic :: Software Development :: Libraries :: Python Modules',
        "Topic :: Software Development :: Debuggers",
        "Topic :: Software Development :: Libraries",
        "Topic :: System :: Logging",
        "Topic :: System :: Monitoring",
        "Natural Language :: English",
    ],
)